//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	CalMosAlgoRmf.h --- C++/F interface between CAL/MOS RMF code
//
//	DESCRIPTION:
//		This header file acts as the interface between the SAS CAL and
//		the Fortran routines to compute a row of the MOS RMF.
//		The package cfortran.h is used for this purpose.
//		The macros PROTOCCALSSFUBS... below declare	C++ callable wrapper
//		functions to routines
//			+ rmfrow
//			+ rmfrowinit
//		the latter being an initialization routines which is needed to load
//		calibration data from the CCF into common blocks.
//		The macros CALMOSALGO_... are to be used in the Cal.
//
//	CHANGE HISTORY:
//		UL, 2001-03-13: 1.0.0: - first version
//		RDS, 2001-04-30: 1.0.0: - for SSE update
//									
//	AUTHOR:
//		U. Lammers, Tue Mar 13 17:48:24 MET 2001
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//
//	$Header: /sasbuild/repositories/sasdev/sas/packages/calmosalgo/src/rmf/CalMosAlgoRmf.h,v 1.8 2010/10/25 16:52:22 rsaxton Exp $
//

#include "common.h"
#include "cfortran.h"

#ifndef CAL_MOS_RMF_H
#define CAL_MOS_RMF_H


#if defined(F90MODPROC)
	#undef F90MODPROC
#endif

#define F90MODPROC(a, b)    CXXFUNC(b, b)

//
// ---( RMF row )------------------------------------------------------------
//
//
//	CALMOSALGO_initRmfRow:	initialization routine; calling this
//						is a pre-requisite for CALMOSALGO_rmfRow
//
PROTOCCALLSFSUB13(F90MODPROC(calmosalgo, rmfrowinit), rmfrowinit,	\
				INT, FLOATV, INTV, INTV, FLOAT, INT,			\
			 FLOAT, FLOAT, FLOATV, FLOATV, FLOAT, FLOAT, INT)

#define CALMOSALGO_initRmfRow(NCH, PARAM, GRADE, NEPTS,		\
							  EWIDTH, NEBIN, THRESHOLD, BACKSIGMA,		\
							  ECHLO, ECHHI, SI_KEDGE, SI_KALPHA, EVENTGRADE) \
	CCALLSFSUB13(RMFROWINIT, rmfrowinit, INT,	\
				 FLOATV, INTV, INTV, FLOAT, INT,			\
				 FLOAT, FLOAT, FLOATV, FLOATV, FLOAT, FLOAT,			\
                                 INT,	\
				 NCH, PARAM, GRADE, NEPTS,						\
				 EWIDTH, NEBIN, THRESHOLD, BACKSIGMA,					\
				 ECHLO, ECHHI, SI_KEDGE, SI_KALPHA, EVENTGRADE)


//
//	CALMOSALGO_rmfRow: compute a single row of the RMF;
//					   CALMOSALGO_initRmfRow has to be called beforehand
//					   to set things up
//
PROTOCCALLSFSUB7(F90MODPROC(calmosalgo, rmfrow), rmfrow,				\
				 FLOAT, FLOAT, INT, INT, INT, FLOATV, FLOATV)

#define CALMOSALGO_rmfRow(ENERGY, SIABSD, NCH, PATT, PATTFRACCHAN,		\
						  PATTFRAC, RESPONSEROW)						\
    CCALLSFSUB7(RMFROW, rmfrow, FLOAT, FLOAT, INT, INT, INT, FLOATV, FLOATV,\
				ENERGY, SIABSD, NCH, PATT, PATTFRACCHAN, PATTFRAC, RESPONSEROW)

//
//	---( auxilliary constants )----------------------------------------------
//
//	have to match those in rmfcommon.f
//
namespace CALMOSALGO {

static const unsigned NPARAM   = 28,
					  NEMAX	   = 1,
					  NALL     = 2,
					  GALL     = 4,
					  NZEROGRAD= 2,
					  GZEROGRAD= 1,
					  MAXCHAN  = 4096,
					  MAXGRADE = 2,
					  PATT_SINGLE = 0,
					  PATT_DOUBLE = 1,
					  PATT_TRIPLE = 2,
					  PATT_QUADRUPLE = 3,
					  PATT_SD	= 4,
					  PATT_SDTQ = 5;

static const float	  EWIDTH   = 3.;	//	native bin width [eV]

}

#endif
