C-UL
C-UL   rmfrowinit: Initialization routine - must be called prior to
C-UL               calling routine rmfrow() below; simply places all
C-UL               its arguments into a common block such that they can
C-UL               be accessed within rmfrow
C-UL
C-RDS   v3.0 - changes from SSE update 29-Apr-2001
C-RDS   v4.0 - changes from SSE update 12-Aug-2010

      subroutine rmfrowinit(nch, 
     *                      param_com, 
     *                      grade_com, nepts_com, ewidth_com,
     *                      nebin_com,
     *                      threshold_com, back_sigma_com,
     *                      echlo_com, echhi_com,
     *                      si_kedge_com, si_kalpha_com, eventGrade)

      implicit none
      include 'rmfcommon.f'

      integer nch  ! The number of channels 
      integer nepts_com(NEMAX), grade_com(NALL)
      integer nebin_com
      real    param_com(NPARAM, NALL)
      real    ewidth_com, threshold_com, back_sigma_com
      real    echlo_com(MAXCHAN), echhi_com(MAXCHAN)

      real    si_kedge_com, si_kalpha_com
      integer eventGrade   ! The actual event grade wanted for this run

      real    si_flo_resn

      integer jg   ! The grade index

      integer i, j, k

      jmax       = 1
      gmax       = 1
      nebin      = nebin_com
      ewidth     = ewidth_com
      threshold  = threshold_com
      back_sigma = back_sigma_com

      do i=1, MAXCHAN
          echlo(i) = echlo_com(i)
          echhi(i) = echhi_com(i)

C Calculate the channel central energies
          echannel(i) = (echhi(i) + echlo(i)) / 2.0

      enddo

      do i=1, NALL
          grade(i) = grade_com(i)
      enddo

      do i=1, NPARAM
              do k=1, NALL
                  param(i, k) = param_com(i, k)
              enddo
      enddo

      si_kedge = si_kedge_com
      si_kalpha = si_kalpha_com

C Set the parameters depending on the selected grade
C eventGrade = 0  -> grade=1    ! singles
C eventGrade = 5  -> grade=2    ! all - 0-12
C 
      if (eventGrade .eq. 0) jg=1
      if (eventGrade .eq. 5) jg=2

C
C Set the values from the parameter array for the correct grade
C
      lowen_frac = param(1,jg)
      lowen_epeak = param(2,jg)
      lowen_resolution = param(3,jg)

      shelf_emin = param(4,jg)

      siesc_norm = param(5,jg)
      siesc_scale = param(6,jg)
      siflo_norm = param(7,jg)
      siflo_scale = param(8,jg)

      cm_secnd_efpos1 = param(9,jg)
      cm_secnd_efpos2 = param(10,jg)

      vgt_blue = param(11,jg)

      resn_p1 = param(12,jg)
      resn_p2 = param(13,jg)

      vgt_norm = param(14,jg)
      vgt_estart = param(15,jg)
      vgt_scale = param(16,jg)
      vgt_min = param(17,jg)
      vgt_secfac = param(18,jg)

      cm_loss_frac = param(19,jg)
      cm_loss_estart = param(20,jg)
      cm_loss_scale = param(21,jg)
      cm_loss_min = param(22,jg)

      cm_secnd_frac = param(23,jg)
      cm_secnd_estart = param(24,jg)
      cm_secnd_scale = param(25,jg)
      cm_secnd_efrac1 = param(26,jg)
      cm_secnd_efrac2 = param(27,jg)
      rmf_tau = param(28,jg)

C Calculate the silicon flouresence resolution
      si_flo_resn = resn_p1 + (resn_p2 * sqrt(si_kalpha))

C      write(*,*)' si_flo_resn: ',si_flo_resn

C Calculate the si flouresence responserow for this energy
      call simple_noloss(si_kalpha, nch, si_flo_resn, si_flo)

C      write(*,*)' si_flo: ',si_flo(1)

      end


C-UL
C-UL  rmfrow : compute response for a single input energy
C-UL
C-UL  ARGUMENTS:
C-UL   IN:
C-UL     energy : input energy [eV]
C-UL     siabsd : Si absorption length [um]
C-UL     nch    : number of channels of output spectrum
C-UL     pattid: pattern ID
C-UL     pattfrac: pattern fraction vectors
C-UL   OUT:
C-UL     responserow : output spectrum of size nch
C-UL
      subroutine rmfrow(energy, siabsd, nch, pattid, pattfracchan,
     *                  pattfrac, responserow)

      implicit none

      include 'rmfcommon.f'

      integer nch, pattid, pattfracchan
      real energy, siabsd
      real responserow(nch), pattfrac(pattfracchan, *)


      real main_norm     
      real main_energy   
      real main_sigma    
      real sloss_alpha   
      real sloss_beta    
      real red_sigma
      real shelf_norm
      real lowe_norm
      real lowe_sigma
      real flo_norm      
      real flo_sigma     
      real esc_norm      
      real esc_sigma

      real escenergy
      real ytotal, x1, x2, xbin, xbin2
      real renorm(MAXGRADE)
      real gauss

      integer k, l, l1, l2, m, m1, elo, ehi
      integer jgmin,jgmax,jemin,jemax,jg,je
      real yrmf(10000), yconv(10000)
      real yold, ypnorm, abit, ctotal, rmfnorm    
      real event_threshold

      real resn
      real esc_energy, esc_resn, siesc_norm_en, siflo_norm_en
      real si_esc(MAXCHAN)

C NB: this code only calculates the response for a given grade type 
C it doesn't average as before. 

C-UL
C-UL   zero responserow
C-UL
       do k=1, nch
          responserow(k) = 0.
       enddo

C
C New code - from rmf_array.pro
C
C   Calculate the resolution at this energy
      resn = resn_p1 + resn_p2 * sqrt(energy)

C   Calculate the main responserow for this energy
      call simple(energy, nch, resn, responserow)

C      write(*,*)' RMF: ',responserow(5), responserow(11)
C      write(*,*)' Res: ',energy,resn,resn_p1,resn_p2

C   Above Si Kedge add escape and flourescence features
      if (energy .gt. si_kedge) then 

         esc_energy = energy - si_kalpha
         esc_resn = resn_p1 + resn_p2 * sqrt(esc_energy)

C       Calculate the si flouresence responserow for this energy
         call simple_noloss(esc_energy, nch, esc_resn, si_esc)

         siesc_norm_en = siesc_norm * 
     &                    exp(-1.0*((energy-si_kedge)
     &                                     /siesc_scale))
         siflo_norm_en = siflo_norm *
     &                    exp(-1.0*((energy-si_kedge)
     &                                     /siflo_scale))
         main_norm = 1.0 - (siesc_norm_en + siflo_norm_en)

C       Add the silicon features
         do k=1,nch
            responserow(k) = responserow(k) * main_norm + 
     &                          siesc_norm_en * si_esc(k) + 
     &                          siflo_norm_en * si_flo(k)
         enddo

C         write(*,*)'SI: ',siesc_norm_en,siflo_norm_en,main_norm,
C     &                    si_esc(5),si_flo(5)

      endif

C      write(*,*)' Response:',energy,responserow(5),responserow(11)

      return

      end
