        subroutine simple(e0, nch, resolution, output)
C
C
C   Phenomonological model for the MOS rmf, without the loss parts
C
C Input:
C  e0        - Photon energy in eV
C  echannel  - Array of channel energies in eV
C  resolution - Native resolution at e0 in eV
C
C Output:
C  minp     - Array containing rmf
C
C Author:
C   Original in IDL:  Steve Sembay (sfs5@star.le.ac.uk)
C

      implicit none

      include 'rmfcommon.f'

      real e0
      integer nch
      real resolution
      real output(MAXCHAN)     ! Output array

      integer nchan
C         parameter (nchan=nch+40)

      real rmf(nch+40)         ! rmf working array

      real ech_ext(nch+40)
      integer lp
      integer count1,count2,count3,count4,count5,count6
      real mainp(nch+40)
      real shelf(nch+40)
      real secnd(nch+40)
      integer sel1(nch+40), sel2(nch+40), sel3(nch+40)
      integer sel4(nch+40), sel5(nch+40), sel6(nch+40)
      double precision red_damp, sec_damp, u1, u2, u3
      double precision u5
      double precision red2, red3, red5
      double precision v0
      double precision blu1
      real totmainp, totshelf, totsecnd, totrmf

      real secnd_frac
      real loss_frac, loss
      real efrac, dx, dy
      real sec_peak
      real ulo, glo(nch+40), totglo
      real slope, const
      real res141

 
C Set NCHAN
      nchan = nch + 40

C Zero all arrays
      do lp=1,nchan
         rmf(lp)=0.0
         mainp(lp)=0.0
         shelf(lp)=0.0
         secnd(lp)=0.0
         ech_ext(lp)=0.0
         sel1(lp)=0
         sel2(lp)=0
         sel3(lp)=0
         sel4(lp)=0
         sel5(lp)=0
         sel6(lp)=0
      end do
C Set useful variables
      res141 = 1.41*resolution

C Add 40 fictious -ve energy channels to echannel array
C
      do lp=1,40
         ech_ext(lp) = -1.0 * echannel(40-lp+1)
      enddo
      do lp=1,nch
         ech_ext(40+lp) = echannel(lp)
      enddo

C Relative fraction of counts in the secondary peak compared to the
C sum of the secondary and shelf components

      if (e0 .lt. cm_secnd_estart) then
         secnd_frac = cm_secnd_frac
      else
         secnd_frac = cm_secnd_frac * 
     &                  exp(-1.0*(e0-cm_secnd_estart)/cm_secnd_scale)
      endif

      secnd_frac=min(max(secnd_frac,0.0),1.0)

C Relative fraction of counts in the loss component (the shelf + secnd 
C components)
C
      if (e0 .lt. cm_loss_estart) then 
         loss_frac = cm_loss_frac
      else
         loss_frac = cm_loss_frac * 
     &                exp(-1.0*(e0-cm_loss_estart)/cm_loss_scale)
      endif

      loss_frac = max(loss_frac, cm_loss_min)
      loss_frac=min(max(loss_frac,0.0),1.0)

C Calculate efrac value
C
      if (e0 .le. cm_secnd_efpos1) then
         efrac = cm_secnd_efrac1
      else if (e0 .ge. cm_secnd_efpos2) then 
         efrac = cm_secnd_efrac2
      else 
         dy = cm_secnd_efrac2 - cm_secnd_efrac1
         dx = cm_secnd_efpos2 - cm_secnd_efpos1
         efrac = cm_secnd_efrac1 + (dy * (e0 - cm_secnd_efpos1) / dx)
      endif

      sec_peak = e0 * efrac

C Find segments for blu and red wings of components
C
      count1=0
      count2=0
      count3=0
      count4=0
      count5=0
      count6=0
 
      do lp=1,nchan
         if (ech_ext(lp) .gt. e0 .and. ech_ext(lp) .lt. 1.5*e0) then
            count1=count1+1
            sel1(count1)=lp
         endif
         if (ech_ext(lp) .le. e0) then
            count2=count2+1
            sel2(count2)=lp
         endif
         if (ech_ext(lp) .le. sec_peak) then
            count3=count3+1
            sel3(count3)=lp
         endif
         if (ech_ext(lp) .ge. sec_peak .and. ech_ext(lp) .le. e0) then
            count4=count4+1
            sel4(count4)=lp
         endif
         if (ech_ext(lp) .le. shelf_emin) then
            count5=count5+1
            sel5(count5)=lp
         endif
         if (ech_ext(lp) .gt. shelf_emin .and. ech_ext(lp) .le. e0) then
            count6=count6+1
            sel6(count6)=lp
         endif
      enddo

C Calculate the voigt dampening parameters for the red wings of the
C main peaks
C
      if (e0 .lt. vgt_estart) then 
         red_damp = vgt_norm
      else 
         red_damp = vgt_norm * exp(-1.0*(e0-vgt_estart)/vgt_scale)
      endif

      red_damp = max(red_damp, DBLE(vgt_min))
      sec_damp = red_damp * vgt_secfac

C Calculate blu Voigt wings (dampening parameter is a small constant here)
C
      if (count1 .gt. 0) then

         call voigt(DBLE(vgt_blue), 0.0d0, v0)

         do lp=1,count1
            u1 = (ech_ext(sel1(lp)) - e0) / res141

            call voigt(DBLE(vgt_blue), u1, blu1)

            mainp(sel1(lp)) = blu1 / v0
            shelf(sel1(lp)) = mainp(sel1(lp))
         enddo

      endif

C      write(*,*)' P2', count2, red_damp, 
C     &  (ech_ext(sel2(1)) - e0) / res141, 
C     &  (ech_ext(sel2(count2)) - e0) / res141

C Calculate red Voigt wings
C
      if (count2 .gt. 0) then 

         call voigt(red_damp, 0.0d0, v0)
         
         do lp=1,count2
            u2 = (ech_ext(sel2(lp)) - e0) / res141

            call voigt(red_damp, u2, red2)

            mainp(sel2(lp)) = red2 / v0
         enddo

      endif

C      write(*,*)' P3', count3
C      write(*,*)'Damp: ',red_damp,sec_damp,mainp(sel1(1)),
C     &             mainp(sel2(1)),sel1(1),sel2(1)

C Calculate red Voigt wings of secondarys
C
      if (count3 .gt. 0) then 

         call voigt(sec_damp, 0.0d0, v0)

         do lp=1,count3
            u3 = (ech_ext(sel3(lp)) - sec_peak) / res141

            call voigt(sec_damp, u3, red3)

            secnd(sel3(lp)) = red3 / v0
         enddo

      endif

C      write(*,*)' P4', count1, count4, count5, count6
C Calculate secondary blue wing
C
      if (count4 .gt. 0) then
         slope = 1.0 / (sec_peak - e0)
         const = -1.0 * slope * e0

         do lp=1,count4
            secnd(sel4(lp)) = const + (slope * ech_ext(sel4(lp)))
         enddo

      endif
C
C Calcuate red Voigt wing of shelf
C
      if (count5 .gt. 0) then

         call voigt(sec_damp, 0.0d0, v0)

         do lp=1,count5
            u5 = (ech_ext(sel5(lp)) - shelf_emin) / res141

            call voigt(sec_damp, u5, red5)

            shelf(sel5(lp)) = red5 / v0
         enddo

      endif

C Calculate shelf
C
      if (count6 .gt. 0) then 
         
         do lp=1,count6
            shelf(sel6(lp)) = 1.0
         enddo
      endif

C Normalise the mainp, shelf and secnd arrays
      totmainp=0.0
      totshelf=0.0
      totsecnd=0.0
      do lp=1,nchan
         totmainp = totmainp + mainp(lp)
         totshelf = totshelf + shelf(lp)
         totsecnd = totsecnd + secnd(lp)
      enddo
      do lp=1,nchan
         mainp(lp) = mainp(lp) / totmainp
         shelf(lp) = shelf(lp) / totshelf
         secnd(lp) = secnd(lp) / totsecnd
      enddo

C Normalise rmf
C
      do lp=1,nchan
         loss = ((1.0-secnd_frac) * shelf(lp)) + 
     &                      (secnd_frac * secnd(lp))
         rmf(lp)  = (loss_frac * loss) + 
     &                     ((1.0-loss_frac)*mainp(lp))
      enddo

C Apparently some elements may be NAN or infinite. remove these and renormalise
C
      totrmf=0.0
      do lp=1,nchan

C       Use trick to check for a NAN
         if ( rmf(lp)+1.0 .eq. rmf(lp) ) then
            rmf(lp)=0.0
         endif

         totrmf = totrmf + rmf(lp)
      enddo

C Normalise the rmf
      do lp=1,nchan
         rmf(lp) = rmf(lp) / totrmf
      enddo

C Add the lowen gaussian component
C
      do lp=1,nchan
         ulo = (ech_ext(lp) - lowen_epeak) / lowen_resolution
         glo(lp) = exp(-0.5 * (ulo**2))
      enddo

      totglo=0.0
      do lp=1,nchan

C       Use trick to check for a NAN
         if ( glo(lp)+1.0 .eq. glo(lp) ) then
            glo(lp)=0.0
         endif

         totglo = totglo + glo(lp)
      enddo

C Set the final rmf using the normalised lowen gaussian component
      do lp=1,nchan
         rmf(lp) = ((1.0 - lowen_frac) * rmf(lp)) + 
     &                             (lowen_frac * glo(lp) / totglo)
      enddo

C Return the result, removing the first 40 channels
C
      do lp=1,nch
         output(lp) = rmf(lp+40)
      enddo

C      write(*,*)' Profile: ',output(1),output(11)

      return 

      end
