        subroutine simple_noloss(e0, nch, resolution, output)
C
C
C   Phenomonological model for the MOS rmf, without the loss parts
C
C Input:
C  e0        - Photon energy in eV
C  nch       - Number of channel energies 
C  resolution - Native resolution at e0 in eV
C
C Output:
C  output     - Array containing rmf
C
C Author:
C   Original in IDL:  Steve Sembay (sfs5@star.le.ac.uk)
C

      implicit none

      include 'rmfcommon.f'

      real e0
      integer nch             ! Number of channels
      real resolution
      real output(MAXCHAN)    ! The returned result

      integer nchan
C         parameter (nchan=nch+40)

      real ech_ext(nch+40)
      integer lp
      integer count1,count2
      real mainp(nch+40)
      integer sel1(nch+40), sel2(nch+40)
      double precision red_damp, u1, u2
      double precision red2
      double precision v0
      double precision blu1
      double precision totmainp

C Set NCHAN
      nchan = nch+40

C Zero the MAINP array
      do lp=1,nchan
         mainp(lp)=0.0
      enddo

C Check that common block vars arrive ok
C      write(*,*)' Inputs,: ',e0, echannel(1), echannel(10),
C     &                                resolution
C      write(*,*)' cm_secnd_frac,: ',cm_secnd_frac
C      write(*,*)' shelf_emin: ',shelf_emin

C Add 40 fictious -ve energy channels to echannel array
C
      do lp=1,40
         ech_ext(lp) = -1.0 * echannel(40-lp+1)
      enddo
      do lp=1,nch
         ech_ext(40+lp) = echannel(lp)
      enddo

C Find segments for blu and red wings of components
C
      count1=0
      count2=0
      do lp=1,nchan
         if (ech_ext(lp) .gt. e0 .and. ech_ext(lp) .lt. 1.5*e0) then
            count1=count1+1
            sel1(count1)=lp
         endif
         if (ech_ext(lp) .le. e0) then
            count2=count2+1
            sel2(count2)=lp
         endif
      enddo
            
C      write(*,*)'COUNT: ',count1,count2,sel2(count2),
C     &                  ech_ext(sel2(count2))

C Calculate the voigt dampening parameters for the red wings of the
C main peaks
C
      if (e0 .lt. vgt_estart) then 
         red_damp = vgt_norm
      else 
         red_damp = vgt_norm * exp(-1.0*(e0-vgt_estart)/vgt_scale)
      endif

      red_damp = max(red_damp, DBLE(vgt_min))

C Calculate blu Voigt wings (dampening parameter is a small constant here)
C
      if (count1 .gt. 0) then

         call voigt(DBLE(vgt_blue),  0.0d0, v0)


         do lp=1,count1
            u1 = (ech_ext(sel1(lp)) - e0) / (1.41 * resolution)

            call voigt(DBLE(vgt_blue), u1, blu1) 

            mainp(sel1(lp)) = blu1 / v0
         enddo

      endif

C Calculate red Voigt wings
C
      if (count2 .gt. 0) then 
         call voigt(red_damp, 0.0d0, v0)
         
         do lp=1,count2
            u2 = (ech_ext(sel2(lp)) - e0) / (1.41 * resolution)

            call voigt(red_damp, u2, red2)

            mainp(sel2(lp)) = red2 / v0
            totmainp = totmainp + mainp(sel2(lp))
         enddo

      endif

C Normalise the mainp array
C     totmainp=0.0
C      do lp=1,nchan
C         totmainp = totmainp + mainp(lp)
C      enddo
C      do lp=1,nchan
C         mainp(lp) = mainp(lp) / totmainp
C      enddo

C Apparently some elements may be NAN or infinite. remove these and renormalise
C
      totmainp=0.0
      do lp=1,nchan

C       Use trick to check for a NAN
         if ( mainp(lp)+1.0 .eq. mainp(lp) ) then
            mainp(lp)=0.0
         endif

         totmainp = totmainp + mainp(lp)
      enddo

C Normalise the mainp array
      do lp=1,nchan
         mainp(lp) = mainp(lp) / totmainp
      enddo
      
C      write(*,*)'MAINP: ',totmainp,mainp(1)

C Return the result, removing the first 40 channels
C
      do lp=1,nch
         output(lp) = mainp(lp+40)
      enddo
      
      return 

      end
